@@ -17,6 +17,7 @@
 #'			\item{url}{URL for the plugin (optional)}
 #'			\item{license}{License the plugin is distributed under (mandatory)}
 #'			\item{category}{A category for this plugin (optional)}
+#'			\item{long.desc}{A long description (optional, defaults to \code{desc})}
 #'		}
 #' @param dependencies A named list with these elements:
 #'		\describe{
@@ -38,6 +39,7 @@
 #'			\item{url}{URL to get the pluginmap (optional)}
 #'		}
 #' @export
+#' @seealso \href{help:rkwardplugins}{Introduction to Writing Plugins for RKWard}
 #' @examples
 #' about.node <- rk.XML.about(
 #' 	name="Square the circle",
@@ -67,10 +69,10 @@
 #' 		c(name="heisenberg.pluginmap", url="http://eternalwondermaths.example.org/hsb"))
 #' )
 #' 
-#' cat(pasteXMLNode(about.node, shine=2))
+#' cat(pasteXML(about.node, shine=2))
 
 
-rk.XML.about <- function(name, author, about=list(desc="SHORT_DESCRIPTION", version="0.01-0", date=Sys.Date(), url="http://EXAMPLE.com", license="GPL (>= 3)"), dependencies=NULL, package=NULL, pluginmap=NULL){
+rk.XML.about <- function(name, author, about=list(desc="SHORT_DESCRIPTION", version="0.01-0", date=Sys.Date(), url="http://EXAMPLE.com", license="GPL (>= 3)", long.desc=NULL), dependencies=NULL, package=NULL, pluginmap=NULL){
 	# sanity checks
 	stopifnot(all(length(name), length(author)) > 0)
 	if(is.null(about)){
@@ -91,6 +93,9 @@ rk.XML.about <- function(name, author, about=list(desc="SHORT_DESCRIPTION", vers
 	if(!"license" %in% names(about)){
 		about[["license"]] <- "GPL (>= 3)"
 	} else {}
+	if(!"long.desc" %in% names(about) | is.null(about[["long.desc"]])){
+		about[["long.desc"]] <- about[["desc"]]
+	} else {}
 
 	## author
 	# - given
@@ -103,119 +108,98 @@ rk.XML.about <- function(name, author, about=list(desc="SHORT_DESCRIPTION", vers
 			author.family <- format(this.author, include="family")
 			author.email  <- format(this.author, include="email", braces=list(email=""))
 			author.role   <- format(this.author, include="role", braces=list(role=""), collapse=list(role=", "))
-			result <- new("XiMpLe.node",
-				name="author",
-				attributes=list(given=author.given, family=author.family, email=author.email, role=author.role))
+			result <- XMLNode("author",
+				attrs=list(
+					given=author.given,
+					family=author.family,
+					email=author.email,
+					role=author.role
+				))
 			return(result)
 		}))
 
-	## package
-	# - name
-	# - min="min_version",
-	# - max="max_version",
-	# - repository
-	# create example, if empty
-	if(is.null(package)){
-		xml.package.example <- new("XiMpLe.node",
-				name="package",
-				attributes=list(
-					name="CHANGE_ME_OR_DELETE_ME",
-					"min_version"="CHANGE_ME_OR_DELETE_ME",
-					"max_version"="CHANGE_ME_OR_DELETE_ME",
-					repository="CHANGE_ME_OR_DELETE_ME"
-					))
-		xml.package <- list(new("XiMpLe.node",
-					name="!--",
-					children=list(xml.package.example)
-			))
-	} else {
-		xml.package <- sapply(package, function(this.package){
-				result <- new("XiMpLe.node",
-					name="package",
-					attributes=list(
-						name=this.package[["name"]],
-						"min_version"=this.package[["min"]],
-						"max_version"=this.package[["max"]],
-						repository=this.package[["repository"]]
-					))
-				return(result)
-			})
-	}
+	###################
+	## the 'package' code is about to be removed in a future release
+	###################
+		## package
+		# - name
+		# - min="min_version",
+		# - max="max_version",
+		# - repository
+		# create example, if empty
+		if(is.null(package)){
+			xml.package <- list()
+		} else {
+			warning("<package> inside <about> is deprecated, use rk.XML.dependencies() instead!")
+			xml.package <- sapply(package, function(this.package){
+					pck.options <- names(this.package)
+					pck.attributes <- list(name=this.package[["name"]])
+					for (this.option in c("min", "max","repository" )){
+						if(this.option %in% pck.options){
+							pck.attributes[[this.option]] <- this.package[[this.option]]
+						} else {}
+					}
+					result <- XMLNode("package", attrs=pck.attributes)
+					return(result)
+				})
+		}
 
-	## pluginmap
-	# - name,
-	# - url
-	# create example, if empty
-	if(is.null(pluginmap)){
-		xml.pluginmap.text <- new("XiMpLe.node",
-					name="",
-					value="If this plugin depends on other pluginmaps, edit this part to your needs:"
-		)
-		xml.pluginmap.example <- new("XiMpLe.node",
-					name="pluginmap",
-					attributes=list(
-						name="CHANGE_ME_OR_DELETE_ME",
-						url="CHANGE_ME_OR_DELETE_ME"
-					)
-			)
-		xml.pluginmap <- list(new("XiMpLe.node",
-					name="!--",
-					children=list(xml.pluginmap.text, xml.pluginmap.example)
-			))
-	} else {
-		xml.pluginmap <- sapply(pluginmap, function(this.pluginmap){
-				result <- new("XiMpLe.node",
-					name="pluginmap",
-					attributes=list(
-						name=this.pluginmap[["name"]],
-						url=this.pluginmap[["url"]]
-					))
-				return(result)
-			})
-	}
+	###################
+	## the 'pluginmap' code is about to be removed in a future release
+	###################
+		## pluginmap
+		# - name,
+		# - url
+		# create example, if empty
+		if(is.null(pluginmap)){
+			xml.pluginmap <- list()
+		} else {
+			warning("<pluginmap> inside <about> is deprecated, use rk.XML.dependencies() instead!")
+			xml.pluginmap <- sapply(pluginmap, function(this.pluginmap){
+					result <- XMLNode("pluginmap",
+						attrs=list(
+							name=this.pluginmap[["name"]],
+							url=this.pluginmap[["url"]]
+						))
+					return(result)
+				})
+		}
 
-	## dependencies
-	# - rkward.min="rkward_min_version",
-	# - rkward.max="rkward_max_version",
-	# - R.min="R_min_verion",
-	# - R.max="R_max_verion"
-	# + package
-	# + pluginmap
-	for (pmap in xml.pluginmap){
-		xml.package[[length(xml.package)+1]] <- pmap
-	}
-	# comment out an example dependency listing if it has no entries
-	if(is.null(dependencies)){
-		R.v <- R.Version()
-		xml.dependencies.text <- new("XiMpLe.node",
-					name="!--",
-					value="If this plugin has dependencies, edit this part to your needs:"
-		)
-		xml.authors[[length(xml.authors)+1]] <- xml.dependencies.text
-		xml.dependencies <- new("XiMpLe.node",
-					name="dependencies",
-					attributes=list(
-						"rkward_min_version"=.rk.app.version,
-						"rkward_max_version"="CHANGE_ME_OR_DELETE_ME",
-						"R_min_verion"=paste(R.v$major, R.v$minor, sep="."),
-						"R_max_verion"="CHANGE_ME_OR_DELETE_ME"
-					),
-					children=xml.package,
-					value=""
-			)
-	} else {
-		xml.dependencies <- new("XiMpLe.node",
-					name="dependencies",
-					attributes=list(
-						"rkward_min_version"=dependencies[["rkward.min"]],
-						"rkward_max_version"=dependencies[["rkward.max"]],
-						"R_min_verion"=dependencies[["R.min"]],
-						"R_max_verion"=dependencies[["R.max"]]
-					),
-					children=xml.package,
-					value=""
-			)
-	}
+	###################
+	## the 'dependencies' code is about to be removed in a future release
+	###################
+		## dependencies
+		# - rkward.min="rkward_min_version",
+		# - rkward.max="rkward_max_version",
+		# - R.min="R_min_version",
+		# - R.max="R_max_version"
+		# + package
+		# + pluginmap
+		for (pmap in xml.pluginmap){
+			xml.package[[length(xml.package)+1]] <- pmap
+		}
+		if(is.null(dependencies)){
+			xml.dependencies <- list()
+		} else {
+			warning("<dependencies> inside <about> is deprecated, use rk.XML.dependencies() instead!")
+			dep.options <- names(dependencies)
+			dep.attributes <- list()
+			if("rkward.min" %in% dep.options){
+				dep.attributes[["rkward_min_version"]] <- dependencies[["rkward.min"]]
+			} else {}
+			if("rkward.max" %in% dep.options){
+				dep.attributes[["rkward_max_version"]] <- dependencies[["rkward.max"]]
+			} else {}
+			if("R.min" %in% dep.options){
+				dep.attributes[["R_min_version"]] <- dependencies[["R.min"]]
+			} else {}
+			if("R.max" %in% dep.options){
+				dep.attributes[["R_max_version"]] <- dependencies[["R.max"]]
+			} else {}
+			xml.dependencies <- XMLNode("dependencies",
+				attrs=dep.attributes,
+				.children=child.list(xml.package, empty=FALSE))
+		}
 
 	## about
 	# - name
@@ -231,19 +215,18 @@ rk.XML.about <- function(name, author, about=list(desc="SHORT_DESCRIPTION", vers
 	if(is.null(xml.authors)){
 		xml.authors <- list()
 	} else {}
-	xml.about <-  new("XiMpLe.node",
-				name="about",
-				attributes=list(
-					name=name,
-					"shortinfo"=about[["desc"]],
-					version=about[["version"]],
-					"releasedate"=about[["date"]],
-					url=about[["url"]],
-					license=about[["license"]],
-					category=about[["category"]]
-				),
-				children=xml.authors
-		)
+	xml.about <-  XMLNode("about",
+		attrs=list(
+			name=name,
+			"shortinfo"=about[["desc"]],
+			"longinfo"=about[["long.desc"]],
+			version=about[["version"]],
+			"releasedate"=about[["date"]],
+			url=about[["url"]],
+			license=about[["license"]],
+			category=about[["category"]]
+		),
+		.children=xml.authors)
 
 	return(xml.about)
 }
