@@ -7,16 +7,17 @@
 #'		or an object of class \code{XiMpLe.node} (whose \code{id} will be extracted and used).
 #' @param value Character string, new value for the attribute.
 #' @param label Character string, label associated with the attribute.
-#' @return A list of objects of class \code{XiMpLe.node}.
+#' @return An object of class \code{XiMpLe.node}.
 #' @export
 #' @seealso
-#'		\code{\link[rkwarddev:rk.XML.components]{rk.XML.components}}
+#'		\code{\link[rkwarddev:rk.XML.components]{rk.XML.components}},
+#'		and the \href{help:rkwardplugins}{Introduction to Writing Plugins for RKWard}
 #' @examples
 #' # define a formula section with varselector and varslots
 #' test.checkbox <- rk.XML.cbox(label="foo", value="foo1", chk=TRUE)
 #' # re-set the attribute
 #' test.attribute <- rk.XML.attribute(test.checkbox, value="bar2", label="bar")
-#' cat(pasteXMLNode(test.attribute))
+#' cat(pasteXML(test.attribute))
 
 rk.XML.attribute <- function(id, value=NULL, label=NULL){
 	# let's see if we need to extract IDs first
@@ -33,10 +34,7 @@ rk.XML.attribute <- function(id, value=NULL, label=NULL){
 		attr.list[["label"]] <- label
 	} else {}
 
-	node <- new("XiMpLe.node",
-			name="attribute",
-			attributes=attr.list
-		)
+	node <- XMLNode("attribute", attrs=attr.list)
 
 	return(node)
 }
