@@ -2,19 +2,20 @@
 #'
 #' This function will create a entry node for menu sections in .pluginmap files.
 #' 
-#' @param component An ID.
+#' @param component A "component" object of class \code{XiMpLe.node}, or an ID.
 #' @param index Integer number to influence the level of menu placement.
-#' @return A list of objects of class \code{XiMpLe.node}.
+#' @return An object of class \code{XiMpLe.node}.
 #' @export
 #' @seealso
 #'		\code{\link[rkwarddev:rk.XML.menu]{rk.XML.menu}},
 #'		\code{\link[rkwarddev:rk.XML.hierarchy]{rk.XML.hierarchy}},
 #'		\code{\link[rkwarddev:rk.XML.component]{rk.XML.component}},
-#'		\code{\link[rkwarddev:rk.XML.components]{rk.XML.components}}
+#'		\code{\link[rkwarddev:rk.XML.components]{rk.XML.components}},
+#'		and the \href{help:rkwardplugins}{Introduction to Writing Plugins for RKWard}
 #' @examples
 #' test.component <- rk.XML.component("My GUI dialog", "plugins/MyGUIdialog.xml")
 #' test.entry <- rk.XML.entry(test.component)
-#' cat(pasteXMLNode(test.entry))
+#' cat(pasteXML(test.entry))
 
 rk.XML.entry <- function(component, index=-1){
 	if(length(component) > 1){
@@ -23,9 +24,9 @@ rk.XML.entry <- function(component, index=-1){
 
 	# check the node names and allow only valid ones
 	if(inherits(component, "XiMpLe.node")){
-		node.name <- component@name
+		node.name <- slot(component ,"name")
 		if(!identical(node.name, "component")){
-			stop(simpleError(paste("Invalid XML node for 'entry': ", node.name, sep="")))
+			stop(simpleError(paste0("Invalid XML node for 'entry': ", node.name)))
 		} else {}
 	} else {}
 
@@ -35,10 +36,7 @@ rk.XML.entry <- function(component, index=-1){
 		attr.list[["index"]] <- index
 	} else {}
 
-	node <- new("XiMpLe.node",
-			name="entry",
-			attributes=attr.list
-		)
+	node <- XMLNode("entry", attrs=attr.list)
 
 	return(node)
 }
