@@ -5,13 +5,15 @@
 #' @return An object of class \code{XiMpLe.node}.
 #' @export
 #' @seealso
-#'		\code{\link[rkwarddev:rk.XML.convert]{rk.XML.convert}},
 #'		\code{\link[rkwarddev:rk.XML.connect]{rk.XML.connect}},
-#'		\code{\link[rkwarddev:rk.XML.logic]{rk.XML.logic}}
-#'		\code{\link[rkwarddev:rk.XML.set]{rk.XML.set}}
+#'		\code{\link[rkwarddev:rk.XML.covert]{rk.XML.convert}},
+#'		\code{\link[rkwarddev:rk.XML.logic]{rk.XML.logic}},
+#'		\code{\link[rkwarddev:rk.XML.set]{rk.XML.set}},
+#'		\code{\link[rkwarddev:rk.XML.switch]{rk.XML.switch}},
+#'		and the \href{help:rkwardplugins}{Introduction to Writing Plugins for RKWard}
 #' @examples
 #' test.external <- rk.XML.external(id="ext_property", default="none")
-#' cat(pasteXMLNode(test.external))
+#' cat(pasteXML(test.external))
 
 rk.XML.external <- function(id, default=NULL){
 	attr.list <- list(id=id)
@@ -20,9 +22,7 @@ rk.XML.external <- function(id, default=NULL){
 		attr.list[["default"]] <- as.character(default)
 	} else {}
 
-	node <- new("XiMpLe.node",
-			name="external",
-			attributes=attr.list)
+	node <- XMLNode("external", attrs=attr.list)
 
 	return(node)
 }
