@@ -1,17 +1,14 @@
 #' Create XML node "include" for RKWard plugins
 #'
 #' @param file A character string, the file name to be included.
-#' @return A list of objects of class \code{XiMpLe.node}.
+#' @return An object of class \code{XiMpLe.node}.
 #' @export
+#' @seealso
+#'		\href{help:rkwardplugins}{Introduction to Writing Plugins for RKWard}
 #' @examples
 #' test.include <- rk.XML.include("../some_file.xml")
-#' cat(pasteXMLNode(test.include))
+#' cat(pasteXML(test.include))
 
 rk.XML.include <- function(file){
-	node <- new("XiMpLe.node",
-			name="include",
-			attributes=list(file=as.character(file))
-		)
-
-	return(node)
+	return(XMLNode("include", attrs=list(file=as.character(file))))
 }
