@@ -4,11 +4,12 @@
 #'
 #' @param snippet Either a character string (the \code{id} of the snippet to be inserted),
 #'		or an object of class \code{XiMpLe.node} (whose \code{id} will be extracted and used; must be a snippet!).
-#' @return A list of objects of class \code{XiMpLe.node}.
+#' @return An object of class \code{XiMpLe.node}.
 #' @export
 #' @seealso
-#'		\code{\link[rkwarddev:rk.XML.snippets]{rk.XML.snippets}}
-#'		\code{\link[rkwarddev:rk.XML.snippet]{rk.XML.snippet}}
+#'		\code{\link[rkwarddev:rk.XML.snippets]{rk.XML.snippets}},
+#'		\code{\link[rkwarddev:rk.XML.snippet]{rk.XML.snippet}},
+#'		and the \href{help:rkwardplugins}{Introduction to Writing Plugins for RKWard}
 #' @examples
 #' # define a formula section with varselector and varslots
 #' test.formula <- rk.XML.vars("Variables", "Fixed", formula.dependent="Dependent")
@@ -16,7 +17,7 @@
 #' test.snippet <- rk.XML.snippet(test.formula)
 #' # now to insert the snippet
 #' test.insert <- rk.XML.insert(test.snippet)
-#' cat(pasteXMLNode(test.insert))
+#' cat(pasteXML(test.insert))
 
 rk.XML.insert <- function(snippet){
 	if(length(snippet) > 1){
@@ -24,19 +25,16 @@ rk.XML.insert <- function(snippet){
 	} else {}
 
 	if(inherits(snippet, "XiMpLe.node")){
-		node.name <- snippet@name
+		node.name <- slot(snippet, "name")
 		if(!identical(node.name, "snippet")){
-			stop(simpleError(paste("Invalid XML node, must be a snippet: ", node.name, sep="")))
+			stop(simpleError(paste0("Invalid XML node, must be a snippet: ", node.name)))
 		} else {}
 	} else {}
 
 	# let's see if we need to extract IDs first
 	attr.list <- list(snippet=check.ID(snippet))
 
-	node <- new("XiMpLe.node",
-			name="insert",
-			attributes=attr.list
-		)
+	node <- XMLNode("insert", attrs=attr.list)
 
 	return(node)
 }
