@@ -1,11 +1,12 @@
 #' Create XML node "preview" for RKWard plugins
 #'
 #' @param label A character string, text label for the preview checkbox.
-#' @return A list of objects of class \code{XiMpLe.node}.
+#' @return An object of class \code{XiMpLe.node}.
 #' @export
+#' @seealso \href{help:rkwardplugins}{Introduction to Writing Plugins for RKWard}
 #' @examples
 #' test.preview <- rk.XML.preview("See a preview?")
-#' cat(pasteXMLNode(test.preview))
+#' cat(pasteXML(test.preview))
 
 rk.XML.preview <- function(label="Preview"){
 	if(!identical(label, "Preview")){
@@ -14,10 +15,7 @@ rk.XML.preview <- function(label="Preview"){
 		attr.list <- list()
 	}
 
-	node <- new("XiMpLe.node",
-			name="preview",
-			attributes=attr.list
-		)
+	node <- XMLNode("preview", attrs=attr.list)
 
 	return(node)
 }
