@@ -8,12 +8,14 @@
 #' @param after A list of objects of class \code{XiMpLe.node}.
 #' @return An object of class \code{XiMpLe.node}.
 #' @export
+#' @seealso
+#'		\href{help:rkwardplugins}{Introduction to Writing Plugins for RKWard}
 #' @examples
-#' cat(pasteXMLNode(rk.XML.stretch()))
+#' cat(pasteXML(rk.XML.stretch()))
 
 #<stretch />
 rk.XML.stretch <- function(before=NULL, after=NULL){
-	strch <- new("XiMpLe.node", name="stretch")
+	strch <- XMLNode("stretch")
 
 	# if called without furter objects, just return the node
 	if(is.null(c(before, after))){
