@@ -7,10 +7,11 @@
 #' @export
 #' @seealso
 #'		\code{\link[rkwarddev:rk.XML.varslot]{rk.XML.varslot}},
-#'		\code{\link[rkwarddev:rk.XML.vars]{rk.XML.vars}}
+#'		\code{\link[rkwarddev:rk.XML.vars]{rk.XML.vars}},
+#'		and the \href{help:rkwardplugins}{Introduction to Writing Plugins for RKWard}
 #' @examples
 #' test.varselector <- rk.XML.varselector("Select some vars")
-#' cat(pasteXMLNode(test.varselector))
+#' cat(pasteXML(test.varselector))
 
 rk.XML.varselector <- function(label=NULL, id.name="auto"){
 	if(identical(id.name, "auto")){
@@ -28,9 +29,7 @@ rk.XML.varselector <- function(label=NULL, id.name="auto"){
 		} else {}
 	}
 
-	node <- new("XiMpLe.node",
-		name="varselector",
-		attributes=attr.list)
+	node <- XMLNode("varselector", attrs=attr.list)
 
 	return(node)
 }
