@@ -3,9 +3,9 @@
 #' \tabular{ll}{
 #' Package: \tab rkwarddev\cr
 #' Type: \tab Package\cr
-#' Version: \tab 0.02-3\cr
-#' Date: \tab 2011-09-30\cr
-#' Depends: \tab R (>= 2.9.0),XiMpLe,rkward (>= 0.5.6)\cr
+#' Version: \tab 0.06-2\cr
+#' Date: \tab 2013-04-04\cr
+#' Depends: \tab R (>= 2.9.0),methods,XiMpLe (>= 0.03-18),rkward (>= 0.5.6)\cr
 #' Enhances: \tab rkward\cr
 #' Encoding: \tab UTF-8\cr
 #' License: \tab GPL (>= 3)\cr
@@ -18,8 +18,7 @@
 #' @aliases rkwarddev-package rkwarddev
 #' @name rkwarddev-package
 #' @docType package
-#' @title A collection of tools for RKWard plugin development.
-#' @author m.eik michalke \email{meik.michalke@@hhu.de}
+#' @title The rkwarddev Package
+#' @author Meik Michalke \email{meik.michalke@@hhu.de}
 #' @keywords package
-roxygen <- function() NULL
-roxygen()
+NULL
